@@ -76,7 +76,6 @@ ProfileManager::ProfileManager()
     , _loadedAllProfiles(false)
     , _loadedFavorites(false)
     , _shortcuts(QMap<QKeySequence, ShortcutData>())
-    , _profileList(nullptr)
 {
     //load fallback profile
     _fallbackProfile = Profile::Ptr(new Profile());
@@ -698,10 +697,3 @@ QKeySequence ProfileManager::shortcut(Profile::Ptr profile) const
     return QKeySequence();
 }
 
-ProfileList *ProfileManager::getProfileList()
-{
-    if (_profileList == nullptr) {
-        _profileList = new ProfileList(true, this);
-    }
-    return _profileList;
-}
