@@ -33,7 +33,6 @@
 
 // Konsole
 #include "Profile.h"
-#include "ProfileList.h"
 
 namespace Konsole {
 /**
@@ -212,7 +211,6 @@ public:
      */
     Profile::Ptr findByShortcut(const QKeySequence &shortcut);
 
-    ProfileList *getProfileList();
 Q_SIGNALS:
 
     /** Emitted when a profile is added to the manager. */
@@ -290,8 +288,6 @@ private:
     // finds out if it's a internal profile or an external one,
     // fixing the path to point to the correct location for the profile.
     QString normalizePath(const QString& path) const;
-
-    ProfileList *_profileList;
 };
 
 /**
